<?php

/**
 * cvgShowCaseWidget - Widget to show video gallery as a showcase
 *
 * @package Cool Video Gallery
 * @author Praveen Rajan
 * @copyright 2010 - 2011
 * @access public
 */
class cvgShowCaseWidget extends WP_Widget {

	function cvgShowCaseWidget() {
		$widget_ops = array('classname' => 'widget_showcase', 'description' => __( 'Show a Cool Video Gallery Showcase') );
		$this->WP_Widget('showcase', __('CVG Showcase'), $widget_ops);
	}

	function widget( $args, $instance ) {
		extract( $args );
			
		$title = apply_filters('widget_title', empty( $instance['title'] ) ? __('Showcase') : $instance['title'], $instance, $this->id_base);
		
		$cvg_core = new CvgCore();
		$out = $cvg_core->videoShowGallery($instance['galleryid']);
		if ( !empty( $out ) ) {
			echo $before_widget;
			if ( $title)
				echo $before_title . $title . $after_title;
		?>
		<div class="cvg_showcase widget">
			<?php echo $out; ?>
		</div>
		<?php
			echo $after_widget;
		}
  
	}
	
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['galleryid'] = (int) $new_instance['galleryid'];
		return $instance;
	}

	function form( $instance ) {
		
		global $wpdb;

		//Defaults
		$instance = wp_parse_args( (array) $instance, array( 'title' => 'CVG Showcase', 'galleryid' => '0') );
		$title  = esc_attr( $instance['title'] );

		$tables = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix ."cvg_gallery ORDER BY 'name' ASC ");
		?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label> <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></p>
		<p>
			<label for="<?php echo $this->get_field_id('galleryid'); ?>"><?php _e('Select Gallery:'); ?></label>
			<select size="1" name="<?php echo $this->get_field_name('galleryid'); ?>" id="<?php echo $this->get_field_id('galleryid'); ?>" class="widefat">
			<?php
			if($tables) {
				foreach($tables as $table) {
				echo '<option value="'.$table->gid.'" ';
				if ($table->gid == $instance['galleryid']) echo "selected='selected' ";
				echo '>'.$table->name.'</option>'."\n\t"; 
				}
			}
			?>
			</select>
		</p>
<?php	
	}
}

// register it
add_action('widgets_init', create_function('', 'return register_widget("cvgShowCaseWidget");'));


/**
 * cvgSlideShow - Widget to show video gallery as a slideshow
 *
 * @package Cool Video Gallery
 * @author Praveen Rajan
 * @copyright 2010 - 2011
 * @access public
 */

class cvgSlideShow extends WP_Widget {

	function cvgSlideShow() {
		$widget_ops = array('classname' => 'widget_slideshow', 'description' => __( 'Show a Cool Video Gallery Slideshow') );
		$this->WP_Widget('slideshow', __('CVG Slideshow'), $widget_ops);
	}

	function widget( $args, $instance ) {
		extract( $args );
			
		$title = apply_filters('widget_title', empty( $instance['title'] ) ? __('Slideshow') : $instance['title'], $instance, $this->id_base);
		
		$cvg_core = new CvgCore();
		$out = $cvg_core->videoShowGallery($instance['galleryid'], true);
		if ( !empty( $out ) ) {
			echo $before_widget;
			if ( $title)
				echo $before_title . $title . $after_title;
		?>
		<div class="cvg_slideshow widget">
			<?php echo $out; ?>
		</div>
		<?php
			echo $after_widget;
		}
  
	}
	
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['galleryid'] = (int) $new_instance['galleryid'];
		return $instance;
	}

	function form( $instance ) {
		
		global $wpdb;

		//Defaults
		$instance = wp_parse_args( (array) $instance, array( 'title' => 'CVG Slideshow', 'galleryid' => '0') );
		$title  = esc_attr( $instance['title'] );

		$tables = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix ."cvg_gallery ORDER BY 'name' ASC ");
		?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label> <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></p>
		<p>
			<label for="<?php echo $this->get_field_id('galleryid'); ?>"><?php _e('Select Gallery:'); ?></label>
			<select size="1" name="<?php echo $this->get_field_name('galleryid'); ?>" id="<?php echo $this->get_field_id('galleryid'); ?>" class="widefat">
			<?php
			if($tables) {
				foreach($tables as $table) {
				echo '<option value="'.$table->gid.'" ';
				if ($table->gid == $instance['galleryid']) echo "selected='selected' ";
				echo '>'.$table->name.'</option>'."\n\t"; 
				}
			}
			?>
			</select>
		</p>
<?php	
	}
}

// register it
add_action('widgets_init', create_function('', 'return register_widget("cvgSlideShow");'));


/**
 * cvgShowCaseWidget($galleryID)
 * Function for templates without widget support
 * 
 * @param integer $galleryID 
 * @return echo the widget content
 * @author Praveen Rajan
 */
function cvgShowCaseWidget($galleryID) {
	$cvg_core = new CvgCore();
	echo $cvg_core->videoShowGallery($galleryID);
}

/**
 * cvgSlideShowWidget($galleryID)
 * Function for templates without widget support
 * 
 * @param integer $galleryID 
 * @return echo the widget content
 * @author Praveen Rajan
 */
function cvgSlideShowWidget($galleryID) {
	$cvg_core = new CvgCore();
	echo $cvg_core->videoShowGallery($galleryID, true);
}
?>